ml4co_kit.solver
==================

.. currentmodule:: ml4co_kit.solver

.. autosummary::
   :toctree: _autosummary
   :recursive:

   ml4co_kit.solver.atsp.base
   ml4co_kit.solver.cvrp.base
   ml4co_kit.solver.mcl.base
   ml4co_kit.solver.mcut.base
   ml4co_kit.solver.mis.base
   ml4co_kit.solver.mvc.base
   ml4co_kit.solver.tsp.base